pub enum Error {
Env {
source: VarError,
},
CurrentDir {
source: Error,
},
Io {
action: &'static str,
path: PathBuf,
source: Error,
},
InvalidIdentityName {
name: String,
},
IdentityNotFound {
name: IdentityName,
},
IdentityAlreadyExists {
name: IdentityName,
},
IdentityBroken {
name: IdentityName,
},
NativeAuthExists,
NoNativeAuthFile,
CodexHomeMissing {
path: PathBuf,
},
UnknownAuthState {
reason: UnknownAuthReason,
},
}Expand description
Error returned by the library API.
Variants
Env
Environment did not contain enough information to resolve Codex home.
CurrentDir
Current working directory could not be read while absolutizing a path.
Io
Filesystem operation failed.
Fields
InvalidIdentityName
Identity name is invalid.
IdentityNotFound
Identity does not exist.
Fields

name: IdentityNameMissing identity name.
IdentityAlreadyExists
Identity already exists.
Fields

name: IdentityNameExisting identity name.
IdentityBroken
Identity entry exists but is unusable.
Fields

name: IdentityNameBroken identity name.
NativeAuthExists
Native auth file exists and would be discarded.
NoNativeAuthFile
No native auth file exists to capture.
CodexHomeMissing
Codex home does not exist.
UnknownAuthState
Current auth state is unknown.
Fields

reason: UnknownAuthReasonReason the auth state is unknown.